"use strict";

var _StringBuilder = require("../../modules/data-types/StringBuilder");

var expectSbValToBe = function expectSbValToBe(sb, val) {
  return expect(sb.toString()).toBe(val);
};

test("Creating new instance with data sets that data as the initial value.", function () {
  var testData = "some data";
  var sb = new _StringBuilder.StringBuilder(testData);
  expectSbValToBe(sb, testData);
});
test("length property returns the correct value when read.", function () {
  var sb = new _StringBuilder.StringBuilder();
  expect(sb.length).toBe(0);
  sb.append("aaaaa");
  expect(sb.length).toBe(5);
});
test("hasValue property returns the correct value when read.", function () {
  var sb = new _StringBuilder.StringBuilder();
  expect(sb.hasValue).toBe(false);
  sb.append("aaaaa");
  expect(sb.hasValue).toBe(true);
});
test("appending a value then reading returns expected string.", function () {
  var sb = new _StringBuilder.StringBuilder("test");
  expectSbValToBe(sb, "test");
  expectSbValToBe(sb.append("ing"), "testing");
});
test("prepending a value then reading returns expected string.", function () {
  var sb = new _StringBuilder.StringBuilder("ing");
  expectSbValToBe(sb, "ing");
  expectSbValToBe(sb.prepend("test"), "testing");
});
test("inserting a value then reading returns expected string.", function () {
  var sb = new _StringBuilder.StringBuilder("tst");
  expectSbValToBe(sb, "tst");
  expectSbValToBe(sb.insertAt(1, "e"), "test");
});
describe("replacing a value", function () {
  test("using a string as parameter then reading returns expected string", function () {
    var sb = new _StringBuilder.StringBuilder("testing");
    expectSbValToBe(sb, "testing");
    expectSbValToBe(sb.replace("ing", "ed"), "tested");
  });
  test("using a RegExp as parameter then reading returns expected string", function () {
    var sb = new _StringBuilder.StringBuilder("testing");
    expectSbValToBe(sb, "testing");
    var regEx = new RegExp(/ing/i);
    expectSbValToBe(sb.replace(regEx, "ed"), "tested");
  });
});
test("clearing the value then reading returns empty string", function () {
  var sb = new _StringBuilder.StringBuilder("testing");
  expectSbValToBe(sb, "testing");
  expectSbValToBe(sb.clear(), "");
});
test("copying a StringBuilder instance returns an instance with the same value", function () {
  var sb = new _StringBuilder.StringBuilder("testing");
  expectSbValToBe(sb, "testing");
  var sbCopy = sb.copy();
  expectSbValToBe(sbCopy, "testing");
  expect(sbCopy).not.toBe(sb);
});
//# sourceMappingURL=StringBuilder.test.js.map