"use strict";

var _time = require("../../modules/date-time/time");

test("now uses fallback if Date.now is not available ", function () {
  Date.now = jest.fn(function () {
    return null;
  });
  expect((0, _time.now)()).toBeGreaterThan(0);
});
test("time returns expected number of seconds", function () {
  Date.now = jest.fn(function () {
    return 10000;
  });
  expect((0, _time.time)()).toBe(10);
});
test("msToTime returns expected string", function () {
  Date.now = jest.fn(function () {
    return 100001;
  });
  expect((0, _time.msToTime)()).toBe("01:01:40.001");
});
test("secsToTimeString returns expected string", function () {
  var secs = 123;
  var secsOnly = (0, _time.secsToTimeString)(secs);
  var includeHrs = (0, _time.secsToTimeString)(secs, true);
  expect(secsOnly).toBe("02:03");
  expect(includeHrs).toBe("00:02:03");
});
test("parseMilliseconds returns expected value", function () {
  var ms = 10000000;
  var res = (0, _time.parseMilliseconds)(ms);
  expect(res).toStrictEqual({
    days: 0,
    hours: 2,
    microseconds: 0,
    milliseconds: 0,
    minutes: 46,
    nanoseconds: 0,
    seconds: 40
  });
});
test("prettifyMilliseconds returns expected value", function () {
  var ms = 1337000000;
  expect((0, _time.prettifyMilliseconds)(ms)).toBe("15d 11h 23m 20s");
});
test("objToMilliseconds returns expected ms", function () {
  var source = {
    days: 15,
    hours: 11,
    minutes: 23,
    seconds: 20
  };
  expect((0, _time.objToMilliseconds)(source)).toBe(1337000000);
});
test("timeZone returns expected string", function () {
  var date = new Date(2022, 0, 1);
  expect((0, _time.timeZone)(date)).toBe("-0");
});
//# sourceMappingURL=time.test.js.map