"use strict";

var _geolocation = require("../../modules/maps/geolocation");

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

describe("isSamePosition", function () {
  test("handles invalid args", function () {
    var invalidArgs = [[null, null], ["invalid", "invalid"], [1, 3], [{}, {}], [{}, {
      coords: {}
    }]];

    for (var _ref3 in invalidArgs) {
      var _ref2 = _slicedToArray(_ref3, 2);

      var first = _ref2[0];
      var second = _ref2[1];
      expect((0, _geolocation.isSamePosition)(first, second)).toBe(false);
    }
  });
  test("returns false for inequal objects", function () {
    var first = {
      coords: {
        latitude: 1
      }
    },
        second = {
      coords: {
        latitude: 10
      }
    };
    expect((0, _geolocation.isSamePosition)(first, second)).toBe(false);
  });
  test("returns true for equal objects", function () {
    var first = {
      coords: {
        latitude: 1,
        longitude: 12,
        altitude: 14,
        accuracy: "78%",
        altitudeAccuracy: 12,
        heading: 12,
        speed: 12
      }
    },
        second = first;
    expect((0, _geolocation.isSamePosition)(first, second)).toBe(true);
  });
});
describe("makePositionObj", function () {
  test("handles invalid args", function () {
    var invalidArgs = [null, {
      latitude: 1,
      longitude: 12,
      altitude: 14,
      accuracy: "78%",
      altitudeAccuracy: 12,
      heading: 12,
      speed: 12
    }, 1, "1", new Date()];

    for (var arg in invalidArgs) {
      expect((0, _geolocation.makePositionObj)(arg)).toBe(null);
    }
  });
  test("returns expected obj", function () {
    var input = {
      timestamp: 12,
      coords: {
        latitude: 1,
        longitude: 12,
        altitude: 14,
        accuracy: "78%",
        altitudeAccuracy: 12,
        heading: 12,
        speed: 12
      },
      extraData: {
        asd: "asd"
      }
    },
        output = {
      timestamp: 12,
      coords: {
        latitude: 1,
        longitude: 12,
        altitude: 14,
        accuracy: "78%",
        altitudeAccuracy: 12,
        heading: 12,
        speed: 12
      }
    };
    expect((0, _geolocation.makePositionObj)(input)).toStrictEqual(output);
  });
});
//# sourceMappingURL=geolocation.test.js.map