"use strict";

var _mapCoordinates = require("../../modules/maps/map-coordinates");

var _CTypeError = _interopRequireDefault(require("../../modules/errors/CTypeError"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe("clampLatitude", function () {
  test("throws CTypeError if the passed value isn't a number", function () {
    var invalidArgs = ["1", function () {
      return null;
    }, ["test"], {}, null];

    var _loop = function _loop(arg) {
      expect(function () {
        return (0, _mapCoordinates.clampLatitude)(arg);
      }).toThrowError(_CTypeError["default"]);
    };

    for (var arg in invalidArgs) {
      _loop(arg);
    }
  });
  test("returns -90 if the passed arg is lower than -90.", function () {
    expect((0, _mapCoordinates.clampLatitude)(-100)).toBe(-90);
  });
  test("returns 90 if the passed arg is higher than 90.", function () {
    expect((0, _mapCoordinates.clampLatitude)(100)).toBe(90);
  });
  test("returns the passed arg if it is higher than -90 and lower than 90.", function () {
    expect((0, _mapCoordinates.clampLatitude)(40)).toBe(40);
  });
});
describe("wrapLongitude", function () {
  test("throws CTypeError if the passed value isn't a number", function () {
    var invalidArgs = ["1", function () {
      return null;
    }, ["test"], {}, null];

    var _loop2 = function _loop2(arg) {
      expect(function () {
        return (0, _mapCoordinates.wrapLongitude)(arg);
      }).toThrowError(_CTypeError["default"]);
    };

    for (var arg in invalidArgs) {
      _loop2(arg);
    }
  });
  test("returns 0 if the passed arg is 360.", function () {
    expect((0, _mapCoordinates.wrapLongitude)(360)).toBe(0);
  });
  test("returns 0 if the passed arg is -360.", function () {
    expect((0, _mapCoordinates.wrapLongitude)(-360)).toBe(0);
  });
  test("returns the passed arg if it is higher than -180 and lower than 180.", function () {
    expect((0, _mapCoordinates.wrapLongitude)(0)).toBe(0);
  });
});
test("normalizeLatitude returns expected value", function () {
  expect((0, _mapCoordinates.normalizeLatitude)(180)).toBe(0);
});
describe("normalizeLongitude", function () {
  expect((0, _mapCoordinates.normalizeLongitude)(360)).toBe(180);
});
//# sourceMappingURL=map-coordinates.test.js.map