"use strict";

var _random = require("../../modules/maths/random");

expect.extend({
  toBeInRange: function toBeInRange(recieved) {
    var expected = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      from: 0,
      to: 0
    };
    var from = expected.from,
        to = expected.to;
    var pass = recieved >= from && recieved <= to;

    var message = function message() {
      return "Value should be in the range a minute of ".concat(from, " and ").concat(to, ". ") + "Received: ".concat(recieved);
    };

    return {
      pass: pass,
      message: message
    };
  }
});
test("randomFromRange returns number in range", function () {
  expect((0, _random.randomFromRange)(1, 4)).toBeInRange({
    from: 1,
    to: 4
  });
});
test("randomNumber returns number in range", function () {
  expect((0, _random.randomNumber)(4)).toBeInRange({
    from: 0,
    to: 4
  });
});
test("randomValue returns a value from the array", function () {
  var source = [1, 3, 5, 8, 9];
  var res = (0, _random.randomValue)(source);
  expect(source.some(function (v) {
    return v === res;
  })).toBe(true);
});
test("shuffleArr returns a shuffled array", function () {
  var source = [1, 3, 5, 8, 9];
  var orig = source.slice(0);
  var res = (0, _random.shuffleArr)(source);
  expect(res.every(function (v) {
    return orig.some(function (ov) {
      return ov === v;
    });
  })).toBe(true);
  expect(res).not.toStrictEqual(orig);
});
test("randomHSLColor returns a string in the expected format", function () {
  // e.g hsl(100, 100%, 100%);
  var expected = new RegExp(/hsl\((\d{1,3}), (\d{1,3})%, (\d{1,3})%\)/g);
  var res = (0, _random.randomHSLColor)(100, 100);
  expect(expected.test(res)).toBe(true);
});
test("uniqueRandom doesn't return the same number twice in a row", function () {
  var uniqRand = (0, _random.uniqueRandom)(0, 10);
  var prev = uniqRand();

  for (var i = 0; i < 20; i++) {
    var curr = uniqRand();
    expect(curr).not.toBe(prev);
    prev = curr;
  }
});
test("uniqueRandomFromArray doesn't return the same value twice in a row", function () {
  var source = [1, 2, 3, 4, 5, 6];
  var uniqRand = (0, _random.uniqueRandomFromArr)(source);
  var prev = uniqRand();

  for (var i = 0; i < 20; i++) {
    var curr = uniqRand();
    expect(curr).not.toBe(prev);
    prev = curr;
  }
});
//# sourceMappingURL=random.test.js.map