"use strict";

var _callbacks = require("../../modules/misc/callbacks");

jest.useFakeTimers();
jest.spyOn(global, "setTimeout");
test("delay waits one seconds before calling delayed func", function () {
  var funcToDelay = jest.fn();
  (0, _callbacks.delay)(funcToDelay, 1000);
  expect(funcToDelay).not.toBeCalled();
  expect(setTimeout).toHaveBeenCalledTimes(1);
  expect(setTimeout).toHaveBeenLastCalledWith(expect.any(Function), 1000);
  jest.runAllTimers();
  expect(funcToDelay).toHaveBeenCalledTimes(1);
});
test("debounce returns a function with a delay", function () {
  var func = jest.fn();
  var debouncedFunc = (0, _callbacks.debounce)(func, 1000);
  expect(func).not.toBeCalled();
  expect(setTimeout).toBeCalled();
  debouncedFunc();
  expect(setTimeout).toBeCalled();
  expect(setTimeout).toHaveBeenLastCalledWith(expect.any(Function), 1000);
  expect(func).not.toBeCalled();
  jest.runAllTimers();
  expect(func).toHaveBeenCalledTimes(1);
});
test("throttle limits the amount of calls a function receives", function () {
  Date.now = jest.fn(function () {
    return 3000;
  });
  var func = jest.fn();
  var throttledFunc = (0, _callbacks.throttle)(func, 1000);

  for (var i = 0; i < 5; i++) {
    throttledFunc();
  }

  expect(func).not.toBeCalled();
  Date.now = jest.fn().mockImplementationOnce(function () {
    return 10000;
  });
  throttledFunc();
  expect(func).toBeCalledTimes(1);
});
//# sourceMappingURL=callbacks.test.js.map