"use strict";

var _functional = require("../../modules/misc/functional");

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

test("curry returns a curried function", function () {
  var funcToCurry = jest.fn(function (arg1, arg2, arg3) {
    return [arg1, arg2, arg3];
  });
  var curried = (0, _functional.curry)(funcToCurry);
  expect(_typeof(curried(1))).toBe("function");
  expect(_typeof(curried(1)(2))).toBe("function");
  expect(curried(1, 2, 3)).toStrictEqual([1, 2, 3]);
  expect(curried(1, 2)(3)).toStrictEqual([1, 2, 3]);
  expect(curried(1)(2)(3)).toStrictEqual([1, 2, 3]);
});
test("chain returns a chained function", function () {
  function is(x) {
    return {
      plus: function plus(_plus) {
        return is(Number(x) + Number(_plus));
      },
      minus: function minus(_minus) {
        return is(Number(x) + Number(_minus));
      },
      equalToTen: function equalToTen() {
        return x === 10;
      }
    };
  }

  var chained = (0, _functional.chain)(is);
  expect(chained(5).plus(5).equalToTen()).toBe(true);
});
test("noActionFunc returns undefined", function () {
  expect((0, _functional.noActionFunc)()).toBeUndefined();
});
test("pick returns a function that gets the expected properties from an object", function () {
  var props = ["first", "last", "age"];
  var obj = {
    first: "Test",
    last: "ing",
    age: 10,
    pet: "dog"
  };

  var picker = _functional.pick.apply(void 0, props);

  expect(picker(obj)).toStrictEqual({
    first: "Test",
    last: "ing",
    age: 10
  });
});
//# sourceMappingURL=functional.test.js.map