"use strict";

var _path = require("../../modules/misc/path");

test("basename returns the base path from a string", function () {
  expect((0, _path.basename)("somepath")).toBe("somepath");
  expect((0, _path.basename)("somepath/test")).toBe("test");
  expect((0, _path.basename)("somepath/test/path/long")).toBe("long");
});
test("getPathExtension returns expected extension", function () {
  expect((0, _path.getPathExtension)("untitled.png")).toBe("png");
  expect((0, _path.getPathExtension)("longpath/tofile/untitled.jpeg")).toBe("jpeg");
  expect((0, _path.getPathExtension)("longpath/tofile/untitled")).toBe("");
});
test("pathInfo returns the expected object", function () {
  expect((0, _path.pathInfo)("untitled.png")).toStrictEqual({
    basename: "untitled.png",
    dirname: ".",
    extension: "png",
    filename: "untitled"
  });
  expect((0, _path.pathInfo)("longpath/tofile/untitled.jpeg")).toStrictEqual({
    basename: "untitled.jpeg",
    dirname: "longpath/tofile",
    extension: "jpeg",
    filename: "untitled"
  });
  expect((0, _path.pathInfo)("/www/index.html")).toStrictEqual({
    basename: "index.html",
    dirname: "/www",
    extension: "html",
    filename: "index"
  });
});
test("fileExtension returns the expected extension", function () {
  expect((0, _path.filenameExtension)("untitled.png")).toBe("png");
  expect((0, _path.filenameExtension)("index.html")).toBe("html");
  expect((0, _path.filenameExtension)("blah.jpeg")).toBe("jpeg");
  expect((0, _path.filenameExtension)("asd.mp4")).toBe("mp4");
  expect((0, _path.filenameExtension)("fgdf.slfpas")).toBe("slfpas");
});
test("dirname returns the expected string", function () {
  expect((0, _path.dirname)("/www/index.html")).toBe("/www");
});
//# sourceMappingURL=path.test.js.map