"use strict";

var _strings = require("../../modules/misc/strings");

test("getDigits returns only numbers in string form", function () {
  expect((0, _strings.getDigits)("testing123")).toBe("123");
  expect((0, _strings.getDigits)("753247532.asdas3/3g")).toBe("75324753233");
});
test("intSeparateThousands returns expected string", function () {
  expect((0, _strings.intSeparateThousands)(100)).toBe("100");
  expect((0, _strings.intSeparateThousands)(1000)).toBe("1,000");
  expect((0, _strings.intSeparateThousands)(10000)).toBe("10,000");
  expect((0, _strings.intSeparateThousands)(100000)).toBe("100,000");
  expect((0, _strings.intSeparateThousands)(100000000)).toBe("100,000,000");
});
describe("trim", function () {
  test("returns a string trimmed on both sides by default", function () {
    var testString = " test ";
    expect((0, _strings.trim)(testString)).toBe("test");
  });
  test("returns a string trimmed only at the end if specified", function () {
    var testString = " test ";
    expect((0, _strings.trim)(testString, " ", {
      trimLeft: true,
      trimRight: false
    })).toBe("test ");
  });
  test("returns a string trimmed only at the end if specified", function () {
    var testString = " test ";
    expect((0, _strings.trim)(testString, " ", {
      trimLeft: false,
      trimRight: true
    })).toBe(" test");
  });
});
test("trimStart returns expected string", function () {
  var testString = " test ";
  expect((0, _strings.trimStart)(testString)).toBe("test ");
});
test("trimEnd returns expected string", function () {
  var testString = " test ";
  expect((0, _strings.trimEnd)(testString)).toBe(" test");
});
test("pluralize returns expected string", function () {
  expect((0, _strings.pluralize)("test", 1)).toBe("test");
  expect((0, _strings.pluralize)("test", 2)).toBe("tests");
});
test("typeToStr returns expected strings", function () {
  expect((0, _strings.typeToStr)(1)).toBe("[object Number]");
  expect((0, _strings.typeToStr)([])).toBe("[object Array]");
  expect((0, _strings.typeToStr)(function () {
    null;
  })).toBe("[object Function]");
});
test("splitOnFirst returns the expected array", function () {
  var testWS = "testing splitting on whitespace";
  var testSlash = "testing/splitting/on/slash";
  expect((0, _strings.splitOnFirst)(testWS, " ")).toStrictEqual(["testing", "splitting on whitespace"]);
  expect((0, _strings.splitOnFirst)(testWS, "/")).toStrictEqual([]);
  expect((0, _strings.splitOnFirst)(testSlash, "/")).toStrictEqual(["testing", "splitting/on/slash"]);
  expect((0, _strings.splitOnFirst)(testSlash, " ")).toStrictEqual([]);
});
test("toSingleQuotes transforms singles to doubles", function () {
  var testString = "\"\"Testing\"\" \"Doubles to singles \"\"";
  expect((0, _strings.toSingleQuotes)(testString)).toBe("''Testing'' 'Doubles to singles ''");
});
test("toDoubleQuotes transforms singles to doubles", function () {
  var testString = "''Testing'' 'Doubles to singles ''";
  expect((0, _strings.toDoubleQuotes)(testString)).toBe("\"\"Testing\"\" \"Doubles to singles \"\"");
});
//# sourceMappingURL=strings.test.js.map