"use strict";

var _validation = require("../../modules/misc/validation");

describe("validatePassword", function () {
  test("returns true by default for a valid strong password", function () {
    var strongPassword = "HasCapNumNSym123!";
    var res = (0, _validation.validatePassword)(strongPassword);
    expect(res[0]).toBe(true);
    expect(res[1]).toStrictEqual({
      correctLength: true,
      hasLower: true,
      hasNumber: true,
      hasSpecial: true,
      hasUpper: true
    });
  });
  test("returns false by default for a invalid strong password", function () {
    var strongPassword = "HasCapNumNSym";
    var res = (0, _validation.validatePassword)(strongPassword);
    expect(res[0]).toBe(false);
    expect(res[1]).toStrictEqual({
      correctLength: true,
      hasLower: true,
      hasNumber: false,
      hasSpecial: false,
      hasUpper: true
    });
  });
  describe("skipping detailed check", function () {
    test("returns true for a strong password", function () {
      var strongPassword = "HasCapNumNSym123!";
      var res = (0, _validation.validatePassword)(strongPassword, {
        skipDetailedCheck: true
      });
      expect(res[0]).toBe(true);
      expect(res[1]).toStrictEqual({});
    });
    test("returns false for an invalid strong password", function () {
      var strongPassword = "HasCapNumNSym";
      var res = (0, _validation.validatePassword)(strongPassword, {
        skipDetailedCheck: true
      });
      expect(res[0]).toBe(false);
      expect(res[1]).toStrictEqual({});
    });
  });
});
//# sourceMappingURL=validation.test.js.map