"use strict";

var _arrays = require("../../modules/object-handling/arrays");

test("distinct returns only unique elements", function () {
  var source = [1, 1, 1, 1, 2, 2, 2, 3, 3, 3, 4];
  expect((0, _arrays.distinct)(source)).toStrictEqual([1, 2, 3, 4]);
});
test("sumOf returns the expected total", function () {
  var source = [1, 3, 5, 7];
  expect((0, _arrays.sumOf)(source)).toBe(16);
});
test("isArrayOfNumber returns expected result", function () {
  var isNums = [1, 3, 5, 7];
  expect((0, _arrays.isArrayOfNumber)(isNums)).toBe(true);
  var isNot = ["tset", 1, 2, 3, 4];
  expect((0, _arrays.isArrayOfNumber)(isNot)).toBe(false);
});
test("firstItem returns expected item.", function () {
  var empty = [];
  expect((0, _arrays.firstItem)(empty)).toBeUndefined();
  var withVals = [1, 3, 4, 5];
  expect((0, _arrays.firstItem)(withVals)).toBe(1);
});
test("lastItem returns expected item.", function () {
  var empty = [];
  expect((0, _arrays.lastItem)(empty)).toBeUndefined();
  var withVals = [1, 3, 4, 5];
  expect((0, _arrays.lastItem)(withVals)).toBe(5);
});
test("firstNested returns expected item.", function () {
  var withoutNested = [1, 3, 4, 5];
  expect((0, _arrays.firstNested)(withoutNested)).toBeUndefined();
  var withNestedArr = [1, [4, 5, 6], [1, 2, 3], 5];
  expect((0, _arrays.firstNested)(withNestedArr)).toStrictEqual([4, 5, 6]);
  var withNestedObj = [1, {
    b: 3
  }, {
    a: 4
  }, 5];
  expect((0, _arrays.firstNested)(withNestedObj)).toStrictEqual({
    b: 3
  });
});
test("lastNested returns expected item.", function () {
  var withoutNested = [1, 3, 4, 5];
  expect((0, _arrays.lastNested)(withoutNested)).toBeUndefined();
  var withNestedArr = [1, [4, 5, 6], [1, 2, 3], 5];
  expect((0, _arrays.lastNested)(withNestedArr)).toStrictEqual([1, 2, 3]);
  var withNestedObj = [1, {
    b: 3
  }, {
    a: 4
  }, 5];
  expect((0, _arrays.lastNested)(withNestedObj)).toStrictEqual({
    a: 4
  });
});
test("minOf returns expected value", function () {
  var empty = [];
  expect((0, _arrays.minOf)(empty)).toBeUndefined();
  var numArray = [1, 2, 3, 4, 5, 6];
  expect((0, _arrays.minOf)(numArray)).toBe(1);
  var strArray = ["test", "ing"];
  expect((0, _arrays.minOf)(strArray)).toBe("ing");
});
test("maxOf returns expected value", function () {
  var empty = [];
  expect((0, _arrays.maxOf)(empty)).toBeUndefined();
  var numArray = [1, 2, 3, 4, 5, 6];
  expect((0, _arrays.maxOf)(numArray)).toBe(6);
  var strArray = ["test", "ing"];
  expect((0, _arrays.maxOf)(strArray)).toBe("test");
});
describe("sortNums", function () {
  test("sorts in ascending order", function () {
    expect((0, _arrays.sortNums)([1, 9, 6, 3, 2, 6], false)).toStrictEqual([1, 2, 3, 6, 6, 9]);
  });
  test("sorts in descending order", function () {
    expect((0, _arrays.sortNums)([1, 9, 6, 3, 2, 6], true)).toStrictEqual([9, 6, 6, 3, 2, 1]);
  });
});
test("removeNulls returns expected array", function () {
  var source = [null, undefined, null, 12, "test", {}, []];
  expect((0, _arrays.removeNulls)(source)).toStrictEqual([12, "test", {}, []]);
});
test("unshift prepends item to array", function () {
  var source = [2, 3, 4, 5];
  (0, _arrays.unshift)(source, 1);
  expect(source[0]).toBe(1);
});
describe("indexWrappedArray", function () {
  test("returns expected item when wrapOverflow is true", function () {
    var proxyArray = (0, _arrays.indexWrappedArray)([1, 2, 3, 4, 5]); // wrapOverflow true by default

    expect(proxyArray[-1]).toBe(5);
    expect(proxyArray[4]).toBe(5);
    expect(proxyArray[5]).toBe(1);
    expect(proxyArray[6]).toBe(2);
    expect(proxyArray[-6]).toBe(5);
  });
  test("returns expected item when wrapOverflow is false", function () {
    var proxyArray = (0, _arrays.indexWrappedArray)([1, 2, 3, 4, 5], {
      wrapOverflow: false
    });
    expect(proxyArray[-1]).toBe(5);
    expect(proxyArray[5]).toBeUndefined();
    expect(proxyArray[5]).toBeUndefined();
    expect(proxyArray[-6]).toBeUndefined();
  });
});
test("arrayMoveMutable shifts item in original list", function () {
  var source = [1, 2, 3];
  (0, _arrays.arrayMoveMutable)(source, 0, 2);
  expect(source[0]).toBe(2);
  expect(source[1]).toBe(3);
  expect(source[2]).toBe(1);
});
test("arrayMoveImmutable returns new list with shifted item", function () {
  var source = [1, 2, 3];
  var res = (0, _arrays.arrayMoveImmutable)(source, 0, 2);
  expect(source[0]).toBe(1);
  expect(source[1]).toBe(2);
  expect(source[2]).toBe(3);
  expect(res[0]).toBe(2);
  expect(res[1]).toBe(3);
  expect(res[2]).toBe(1);
});
//# sourceMappingURL=arrays.test.js.map