"use strict";

var _clone = require("../../modules/object-handling/clone");

test("cloneArr returns expected item", function () {
  var source = [1, 2, 3];
  var clone = (0, _clone.cloneArr)(source);
  expect(clone).toStrictEqual(source);
  expect(clone === source).toBe(false); // different references
});
describe("cloneDeep", function () {
  test("returns expected object when using complex: false", function () {
    var source = [1, 2, 3];
    var clone = (0, _clone.cloneDeep)(source, {
      complex: false
    });
    expect(clone).toStrictEqual(source);
    expect(clone === source).toBe(false); // different references
  });
  test("returns expected object when using complex: true", function () {
    var source = [1, 2, 3];
    var clone = (0, _clone.cloneDeep)(source, {
      complex: true
    });
    expect(clone).toStrictEqual(source);
    expect(clone === source).toBe(false); // different references
  });
});
test("extend adds the expected properties to source", function () {
  var source = {
    first: "blah",
    last: "blah"
  };
  (0, _clone.extend)(source, {
    age: 20
  }, {
    pet: "dog"
  });
  expect(source).toEqual({
    age: 20,
    pet: "dog",
    first: "blah",
    last: "blah"
  });
  (0, _clone.extend)(source, {
    test: true
  });
  expect(source).toEqual({
    test: true,
    age: 20,
    pet: "dog",
    first: "blah",
    last: "blah"
  });
});
test("shallowExtend adds the expected properties to source", function () {
  var source = {
    a: {
      b: 1,
      c: 2
    },
    d: 4
  };
  (0, _clone.extendShallow)(source, {
    a: {
      e: 5,
      f: 8
    },
    h: 12
  });
  expect(source).toEqual({
    a: {
      e: 5,
      f: 8
    },
    d: 4,
    h: 12
  });
});
test("deepObjectExtend adds the expected properties to source", function () {
  var source = {
    a: {
      b: 1,
      c: 2
    },
    d: 4
  };
  (0, _clone.deepObjectExtend)(source, {
    a: {
      e: 5,
      f: 8
    },
    h: 12
  });
  expect(source).toEqual({
    a: {
      b: 1,
      c: 2,
      e: 5,
      f: 8
    },
    d: 4,
    h: 12
  });
});
test("deepObjectCloningExtend adds the expected properties to source", function () {
  var source = {
    a: {
      b: 1,
      c: 2
    },
    d: 4
  };
  (0, _clone.deepObjectCloningExtend)(source, {
    a: {
      e: 5,
      f: 8
    },
    h: 12
  });
  expect(source).toEqual({
    a: {
      b: 1,
      c: 2,
      e: 5,
      f: 8
    },
    d: 4,
    h: 12
  });
});
test("extendDecorate adds the expected properties to source", function () {
  var source = {
    a: {
      b: 1,
      c: 2
    },
    d: 4
  };
  (0, _clone.extendDecorate)(source, {
    a: {
      e: 5,
      f: 8
    },
    h: 12
  });
  expect(source).toEqual({
    a: {
      b: 1,
      c: 2,
      e: 5,
      f: 8
    },
    d: 4,
    h: 12
  });
});
test("cloneRegExp returns new instance with same value", function () {
  var source = new RegExp(/(\w|\d){2,4}/);
  var clone = (0, _clone.cloneRegExp)(source);
  expect(source.toString()).toBe(clone.toString());
  expect(clone === source).not.toBe(true);
});
//# sourceMappingURL=clone.test.js.map