"use strict";

var _compare = require("../../modules/object-handling/compare");

test("is returns expected boolean", function () {
  expect((0, _compare.is)(1, 1)).toBe(true);
  expect((0, _compare.is)(1, 2)).toBe(false);
  expect((0, _compare.is)("asd", "asd")).toBe(true);
  expect((0, _compare.is)("asd", "dsa")).toBe(false);
  expect((0, _compare.is)([], [])).toBe(false); // shallow compare

  expect((0, _compare.is)([], ["dsa"])).toBe(false);
});
test("isObjPropEqual returns expected boolean", function () {
  var objA = {
    a: 0,
    b: 6,
    c: 12
  };
  var objB = {
    a: 0,
    b: 8,
    c: 12
  };
  expect((0, _compare.isObjPropEqual)(objA, objB, "a")).toBe(true);
  expect((0, _compare.isObjPropEqual)(objA, objB, "b")).toBe(false);
  expect((0, _compare.isObjPropEqual)(objA, objB, "a")).toBe(true);
});
test("isEqualShallow returns expected boolean", function () {
  var obj1 = {
    a: 0,
    b: 6,
    c: 12
  };
  var obj2 = {
    a: 0,
    b: 8,
    c: 12
  };
  expect((0, _compare.isEqualShallow)(obj1, obj2)).toBe(false);
  var obj3 = {
    a: 0,
    b: 8,
    c: 12
  };
  var obj4 = {
    a: 0,
    b: 8,
    c: 12
  };
  expect((0, _compare.isEqualShallow)(obj3, obj4)).toBe(true);
  var obj5 = {
    a: 0,
    b: {
      d: 5
    },
    c: 12
  };
  var obj6 = {
    a: 0,
    b: {
      d: 5
    },
    c: 12
  };
  expect((0, _compare.isEqualShallow)(obj5, obj6)).toBe(false);
});
test("isArrayEqualDeep returns expected boolean", function () {
  var arr1 = [[1, 2, 3], [4, 5, 6]];
  var arr2 = [[1, 2, 3], [4, 5, 6]];
  expect((0, _compare.isArrEqualDeep)(arr1, arr2)).toBe(true);
  var arr3 = [[4, 5, 6], [4, 5, 6]];
  var arr4 = [[4, 2, 3], [4, 5, 6]];
  expect((0, _compare.isArrEqualDeep)(arr3, arr4)).toBe(false);
});
test("isObjEqualDeep returns expected boolean", function () {
  var obj1 = [{
    a: [1, 2, 3],
    b: [4, 5, 6]
  }];
  var obj2 = [{
    a: [1, 2, 3],
    b: [4, 5, 6]
  }];
  expect((0, _compare.isObjEqualDeep)(obj1, obj2)).toBe(true);
  var obj3 = [{
    a: [1, 2, 3],
    b: [4, 5, 6]
  }];
  var obj4 = [{
    a: [6, 5, 4],
    b: [1, 2, 3]
  }];
  expect((0, _compare.isObjEqualDeep)(obj3, obj4)).toBe(false);
});
test("partialShallowEqual returns expected boolean", function () {
  var source = {
    name: "Test",
    age: 20,
    pet: "dog"
  };
  expect((0, _compare.partialShallowEqual)(source, {
    pet: "dog"
  })).toBe(true);
  expect((0, _compare.partialShallowEqual)(source, {
    age: 20,
    pet: "dog"
  })).toBe(true);
  expect((0, _compare.partialShallowEqual)(source, {
    phone: 78,
    age: 20,
    pet: "dog"
  })).toBe(false);
});
test("objDiffShallow returns expected value", function () {
  var objA = {
    name: "Test",
    age: 20,
    pet: "dog"
  };
  var objB = {
    name: "Test",
    pet: "cat"
  };
  expect((0, _compare.objDiffShallow)(objA, objB)).toStrictEqual({
    a: {
      age: 20,
      pet: "dog"
    },
    b: {
      pet: "cat"
    }
  });
});
//# sourceMappingURL=compare.test.js.map