"use strict";

var _introspection = require("../../modules/object-handling/introspection");

test("isPrimitiveType returns expected boolean", function () {
  var primitives = [1, "2", false, null, undefined];
  primitives.forEach(function (val) {
    return expect((0, _introspection.isPrimitiveType)(val)).toBe(true);
  });
  var references = [[], {}, function () {
    return null;
  }];
  references.forEach(function (val) {
    return expect((0, _introspection.isPrimitiveType)(val)).toBe(false);
  });
});
test("isInt returns expected boolean", function () {
  var valid = 1;
  expect((0, _introspection.isInt)(valid)).toBe(true);
  var invalid = [new Date(), "1", [], {}, function () {
    return null;
  }];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isInt)(val)).toBe(false);
  });
});
test("isIntString returns expected boolean", function () {
  var valid = "123";
  expect((0, _introspection.isIntString)(valid)).toBe(true);
  var invalid = "test";
  expect((0, _introspection.isIntString)(invalid)).toBe(false);
});
test("isIntOrIntString returns expected boolean", function () {
  var valid = ["123", 123];
  valid.forEach(function (val) {
    return expect((0, _introspection.isIntOrIntString)(val)).toBe(true);
  });
  var invalid = "test";
  expect((0, _introspection.isIntOrIntString)(invalid)).toBe(false);
});
test("isNullOrEmpty returns expected boolean", function () {
  var nullStr = null;
  expect((0, _introspection.isNullOrEmpty)(nullStr)).toBe(true);
  var undefStr = undefined;
  expect((0, _introspection.isNullOrEmpty)(undefStr)).toBe(true);
  var emptyStr = "";
  expect((0, _introspection.isNullOrEmpty)(emptyStr)).toBe(true);
  var nonEmptyStr = "test";
  expect((0, _introspection.isNullOrEmpty)(nonEmptyStr)).toBe(false);
});
test("isNullOrWhitespace returns expected boolean", function () {
  var nullStr = null;
  expect((0, _introspection.isNullOrWhiteSpace)(nullStr)).toBe(true);
  var undefStr = undefined;
  expect((0, _introspection.isNullOrWhiteSpace)(undefStr)).toBe(true);
  var whitespaceStr = " ";
  expect((0, _introspection.isNullOrWhiteSpace)(whitespaceStr)).toBe(true);
  var emptyStr = "";
  expect((0, _introspection.isNullOrWhiteSpace)(emptyStr)).toBe(false);
});
test("isJSONString returns expected boolean", function () {
  var valid = "1";
  expect((0, _introspection.isJSONString)(valid)).toBe(true);
  var invalid = "['test'";
  expect((0, _introspection.isJSONString)(invalid)).toBe(false);
});
test("isTrue returns expected boolean", function () {
  var valid = true;
  expect((0, _introspection.isTrue)(valid)).toBe(true);
  var invalid = false;
  expect((0, _introspection.isTrue)(invalid)).toBe(false);
  var num = 1;
  expect((0, _introspection.isTrue)(num)).toBe(false);
});
test("isTruthy returns expected boolean", function () {
  var valid = [1, "1", true, [], {}];
  valid.forEach(function (val) {
    return expect((0, _introspection.isTruthy)(val)).toBe(true);
  });
  var invalid = [0, "", false, null, undefined];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isTruthy)(val)).toBe(false);
  });
});
test("allTruthy returns expected boolean", function () {
  var valid = [1, "1", true];
  expect(_introspection.allTruthy.apply(void 0, valid)).toBe(true);
  var invalid = [0, "", false, null, undefined, [], {}];
  expect(_introspection.allTruthy.apply(void 0, invalid)).toBe(false);
});
test("isUndefined returns expected boolean", function () {
  var valid = undefined;
  expect((0, _introspection.isUndefined)(valid)).toBe(true);
  var invalid = [1, "1", {}, [], new Date(), null];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isUndefined)(val)).toBe(false);
  });
});
test("isReferenceType returns expected boolean", function () {
  var primitives = [1, "2", false, null, undefined];
  primitives.forEach(function (val) {
    return expect((0, _introspection.isReferenceType)(val)).toBe(false);
  });
  var references = [[], {}, function () {
    return null;
  }];
  references.forEach(function (val) {
    return expect((0, _introspection.isReferenceType)(val)).toBe(true);
  });
});
test("isObject returns expected boolean", function () {
  var valid = [{}, {
    name: ""
  }, {
    a: []
  }];
  valid.forEach(function (val) {
    return expect((0, _introspection.isObject)(val)).toBe(true);
  });
  var invalid = [1, "2", false, null, undefined];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isObject)(val)).toBe(false);
  });
});
test("isObjectLiteral returns expected boolean", function () {
  var valid = [{}, {
    name: ""
  }, {
    a: []
  }];
  valid.forEach(function (val) {
    return expect((0, _introspection.isObjectLiteral)(val)).toBe(true);
  });
  var invalid = [1, "2", false, null, undefined];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isObjectLiteral)(val)).toBe(false);
  });
});
test("isObjectEmpty returns expected boolean", function () {
  var valid = {};
  expect((0, _introspection.isObjectEmpty)(valid)).toBe(true);
  var invalid = {
    name: ""
  };
  expect((0, _introspection.isObjectEmpty)(invalid)).toBe(false);
});
test("isArray returns expected boolean", function () {
  var valid = [[], [12], ["test"], [[]]];
  valid.forEach(function (val) {
    return expect((0, _introspection.isArray)(val)).toBe(true);
  });
  var invalid = [{}, 12, "test", function () {
    return null;
  }];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isArray)(val)).toBe(false);
  });
});
test("isCallable returns expected boolean", function () {
  var valid = function valid() {
    return null;
  };

  expect((0, _introspection.isCallable)(valid)).toBe(true);
  var invalid = [{}, 12, "test", new Date(), []];
  invalid.forEach(function (val) {
    return expect((0, _introspection.isCallable)(val)).toBe(false);
  });
});
test("safeHasOwnProperty returns expected boolean", function () {
  var source = {
    name: "Test",
    age: 20,
    pet: "Dog"
  };
  expect((0, _introspection.safeHasOwnProperty)(source, "name")).toBe(true);
  expect((0, _introspection.safeHasOwnProperty)(source, "age")).toBe(true);
  expect((0, _introspection.safeHasOwnProperty)(source, "pet")).toBe(true);
  expect((0, _introspection.safeHasOwnProperty)(source, "address")).toBe(false);
});
test("hasCyclicReference returns expected boolean", function () {
  var nonCyclic = {
    a: 1,
    b: 3
  };
  expect((0, _introspection.hasCyclicReference)(nonCyclic)).toBe(false);
  var cyclic = {
    otherData: 123
  };
  cyclic.myself = cyclic;
  expect((0, _introspection.hasCyclicReference)(cyclic)).toBe(true);
});
//# sourceMappingURL=introspection.test.js.map