"use strict";

var _nestedProperties = require("../../modules/object-handling/nested-properties");

test("getNestedPropertyValue returns expected object", function () {
  var source = {
    a: {
      b: {
        c: {
          d: 4
        }
      }
    }
  };
  expect((0, _nestedProperties.getNestedPropertyValue)(source, ["a", "b", "c", "d"])).toStrictEqual(4);
});
test("hasNestedPropertyValue returns expected bolean", function () {
  var source = {
    a: {
      b: {
        c: {
          d: 4
        }
      }
    }
  };
  expect((0, _nestedProperties.hasNestedPropertyValue)(source, ["a", "b", "c", "d"])).toBe(true);
  expect((0, _nestedProperties.hasNestedPropertyValue)(source, ["e", "f"])).toBe(false);
});
test("setNestedPropertyValue sets expected value", function () {
  var source = {
    a: {
      b: {
        c: {
          d: 4
        }
      }
    }
  };
  (0, _nestedProperties.setNestedPropertyValue)(source, ["a", "b", "c", "d"], 10);
  expect(source.a.b.c.d).toBe(10);
});
test("nestedMapSet sets expected value", function () {
  var mapA = new Map();
  var mapB = new Map();
  var mapC = new Map();
  var mapD = new Map();
  mapD.set("d", 4);
  mapC.set("c", mapD);
  mapB.set("b", mapC);
  mapA.set("a", mapB);
  (0, _nestedProperties.nestedMapSet)(mapA, ["a", "b", "c", "d"], 10);
  expect(mapD.get("d")).toBe(10);
});
test("nestedMapHas returns expected boolean", function () {
  var mapA = new Map();
  var mapB = new Map();
  var mapC = new Map();
  var mapD = new Map();
  mapD.set("d", 4);
  mapC.set("c", mapD);
  mapB.set("b", mapC);
  mapA.set("a", mapB);
  expect((0, _nestedProperties.nestedMapHas)(mapA, ["a", "b", "c", "d"])).toBe(true);
});
test("nestedMapGet returns expected value", function () {
  var mapA = new Map();
  var mapB = new Map();
  var mapC = new Map();
  var mapD = new Map();
  mapD.set("d", 4);
  mapC.set("c", mapD);
  mapB.set("b", mapC);
  mapA.set("a", mapB);
  expect((0, _nestedProperties.nestedMapGet)(mapA, ["a", "b", "c", "d"])).toBe(4);
});
test("nestedTreeMapHas returns expected boolean", function () {
  var map = new Map(new Map([["whole numbers", [1, 2, 3, 4]], ["Decimal numbers", [1.1, 1.2, 1.3, 1.4]], ["negative numbers", [-1, -2, -3, -4]]]));
  expect((0, _nestedProperties.nestedTreeMapHas)(map, ["whole numbers"])).toBe(true);
});
test("nestedTreeMapSet", function () {
  var map = new Map(new Map([["whole numbers", [0]], ["Decimal numbers", [1.1, 1.2, 1.3, 1.4]], ["negative numbers", [-1, -2, -3, -4]]]));
  (0, _nestedProperties.nestedTreeMapSet)(map, ["whole numbers"], [1]); // expect(nestedMapGet(map, ["whole numbers"])).toStrictEqual([1]);
});
test("nestedTreeMapGet", function () {
  var map = new Map(new Map([["whole numbers", [0]], ["Decimal numbers", [1.1, 1.2, 1.3, 1.4]], ["negative numbers", [-1, -2, -3, -4]]]));
  expect((0, _nestedProperties.nestedMapGet)(map, ["whole numbers"])).toStrictEqual([0]);
});
//# sourceMappingURL=nested-properties.test.js.map