"use strict";

var _objects = require("../../modules/object-handling/objects");

test("mapObject returns the expected object", function () {
  var source = {
    a: 4,
    b: 4,
    c: 0
  };

  var mapFunc = function mapFunc(val, key, index) {
    return val = val * index + index;
  };

  var res = (0, _objects.mapObject)(source, mapFunc);
  expect(res).toStrictEqual({
    a: 0,
    b: 5,
    c: 2
  });
});
test("arrToObject returns expected object", function () {
  var source = [1, 2, 3, 4];

  var mapFunc = function mapFunc(val, index, arr) {
    return ["key".concat(index), "value".concat(val)];
  };

  var res = (0, _objects.arrToObject)(source, mapFunc);
  expect(res).toStrictEqual({
    key0: "value1",
    key1: "value2",
    key2: "value3",
    key3: "value4"
  });
});
test("selectWhere returns expected properties", function () {
  var source = {
    name: "test",
    age: 20,
    num: 200
  };

  var func = function func(val) {
    return typeof val === "number";
  };

  var res = (0, _objects.selectWhere)(source, func);
  expect(res).toStrictEqual({
    age: 20,
    num: 200
  });
});
test("getPrototypes returns expected array", function () {
  var source = {
    name: "test",
    age: 20,
    num: 200
  };
  var expected = ["name", "age", "num", "constructor", "__defineGetter__", "__defineSetter__", "hasOwnProperty", "__lookupGetter__", "__lookupSetter__", "isPrototypeOf", "propertyIsEnumerable", "toString"];
  expect((0, _objects.getPrototypes)(source, {
    stopAt: "toString",
    includeStop: true
  })).toStrictEqual(expected);
});
test("prop defines a property on a object with getter and setter", function () {
  var obj = {};
  (0, _objects.prop)(obj, "test", function () {
    return 1;
  }, function (val) {
    return val;
  });
  obj.test = 4;
  expect(obj.test).toBe(1);
});
test("defineProperty works", function () {
  var obj = {
    name: "Test",
    age: 20
  };
  (0, _objects.defineProperty)(obj, "altAge", {
    get: function get() {
      return this.age;
    }
  });
  expect(obj.altAge).toBe(20);
});
test("completeObjectAssign", function () {
  var obj = {
    name: "Test"
  };
  var source = [{
    age: 20
  }, {
    pet: "dog"
  }];
  expect(_objects.completeObjectAssign.apply(void 0, [obj].concat(source))).toStrictEqual({
    name: "Test",
    age: 20,
    pet: "dog"
  });
});
//# sourceMappingURL=objects.test.js.map